@@ -1,6 +1,6 @@
 # Deformatting ####
 
-#' Modifying network formats
+#' Modifying network formats by removing information
 #' 
 #' @description
 #'   These functions reformat manynet-consistent data.
@@ -159,7 +159,7 @@ to_unweighted.matrix <- function(.data, threshold = 1) {
 #' @export
 to_unweighted.data.frame <- function(.data, threshold = 1) {
   if(is_edgelist(.data)) .data[,1:2]
-  else cli::cli_abort("Not an edgelist")
+  else snet_abort("Not an edgelist")
 }
 
 #' @rdname manip_deformat
@@ -180,7 +180,7 @@ to_unsigned.matrix <- function(.data,
   } else if (keep == "negative"){
     out[out > 0] <- 0
     out <- abs(out)
-  } else cli::cli_abort("Indicate whether 'positive' or 'negative' ties should be kept.")
+  } else snet_abort("Indicate whether 'positive' or 'negative' ties should be kept.")
   out
 }
 
@@ -195,7 +195,7 @@ to_unsigned.data.frame <- function(.data,
     } else if (keep == "negative"){
       out$sign[out$sign > 0] <- 0
       out$sign <- out$sign(out)
-    } else cli::cli_abort("Indicate whether 'positive' or 'negative' ties should be kept.")
+    } else snet_abort("Indicate whether 'positive' or 'negative' ties should be kept.")
   }
   out
 }
@@ -592,7 +592,7 @@ to_named.network <- function(.data, names = NULL) {
 .get_babynames <- function(n){
   indic <- seq(from=1, length.out=n) %% 26
   indic[indic == 0] <- 26
-  mnet_info("Assigning alphabetic baby names at random.")
+  snet_info("Assigning alphabetic baby names at random.")
   # table(stringr::str_extract(manynet:::baby_names, "^."))
   vapply(indic, 
          function(x){
@@ -609,7 +609,7 @@ to_directed <- function(.data) UseMethod("to_directed")
 #' @export
 to_directed.igraph <- function(.data) {
   if(!is_directed.igraph(.data)){
-    mnet_info("Directions are assigned to existing ties at random.")
+    snet_info("Directions are assigned to existing ties at random.")
     igraph::as_directed(.data, mode = "random")
   } else .data
 }
@@ -643,7 +643,7 @@ to_signed <- function(.data, mark = NULL) UseMethod("to_signed")
 to_signed.matrix <- function(.data, mark = NULL){
   if(is.null(mark)){
     out <- ifelse(stats::runif(length(.data))>=0.5, .data, -.data)  
-    mnet_info("Since no mark given, signs are generated by splitting",
+    snet_info("Since no mark given, signs are generated by splitting",
               "a uniform distribution.")
   } else out <- ifelse(mark, .data[.data!=0], -.data[.data!=0])
   if(is_labelled(.data)){
@@ -664,7 +664,7 @@ to_signed.data.frame <- function(.data, mark = NULL){
 to_signed.tbl_graph <- function(.data, mark = NULL){
   if(is.null(mark)){
     ties <- net_ties(.data)
-    mnet_info("Since no mark given, signs are generated by splitting",
+    snet_info("Since no mark given, signs are generated by splitting",
               "a uniform distribution.")
     .data %>% mutate_ties(sign = ifelse(stats::runif(ties)>=0.5, 1, -1))
   } else .data %>% mutate_ties(sign = ifelse(mark, 1, -1))
@@ -692,7 +692,7 @@ to_weighted <- function(.data, measure = NULL) UseMethod("to_weighted")
 to_weighted.tbl_graph <- function(.data, measure = NULL){
   if(is.null(measure)){
     measure <- stats::rpois(net_ties(.data), lambda = 4)
-    mnet_info("Since no measure values given, weights are generated from",
+    snet_info("Since no measure values given, weights are generated from",
               "a Poisson distribution with lambda = 4.")
   }
   .data %>% mutate_ties(weight = measure)
