@@ -23,12 +23,14 @@
 #'   other <- create_filled(4) %>% mutate(name = c("A", "B", "C", "D"))
 #'   mutate_ties(other, form = 1:6) %>% filter_ties(form < 4)
 #'   add_tie_attribute(other, "weight", c(1, 2, 2, 2, 1, 2))
-#' @name add_ties
+#' @name manip_ties
 NULL
 
-#' @rdname add_ties
+#' @rdname manip_ties
 #' @param ties The number of ties to be added or an even list of ties.
 #' @importFrom igraph add_edges
+#' @examples
+#' ison_adolescents %>% add_ties(c("Betty","Tina")) %>% graphr()
 #' @export
 add_ties <- function(.data, ties, attribute = NULL) UseMethod("add_ties")
 
@@ -47,8 +49,11 @@ add_ties.network <- function(.data, ties, attribute = NULL){
   as_network(add_ties(as_igraph(.data), ties, attribute))
 }
 
-#' @rdname add_ties
+#' @rdname manip_ties
 #' @importFrom igraph delete_edges
+#' @examples
+#' delete_ties(ison_adolescents, 3)
+#' delete_ties(ison_adolescents, "Alice|Sue")
 #' @export
 delete_ties <- function(.data, ties) UseMethod("delete_ties")
 
@@ -57,7 +62,17 @@ delete_ties.igraph <- function(.data, ties){
   igraph::delete_edges(.data, edges = ties)
 }
 
-#' @rdname add_ties
+#' @export
+delete_ties.tbl_graph <- function(.data, ties){
+  as_tidygraph(igraph::delete_edges(.data, edges = ties))
+}
+
+#' @export
+delete_ties.network <- function(.data, ties){
+  as_network(igraph::delete_edges(as_igraph(.data), edges = ties))
+}
+
+#' @rdname manip_ties
 #' @importFrom igraph edge_attr
 #' @export
 add_tie_attribute <- function(.data, attr_name, vector){
@@ -71,7 +86,7 @@ add_tie_attribute <- function(.data, attr_name, vector){
                         "igraph, tidygraph, or network objects or data frame edgelists."))
 }
 
-#' @rdname add_ties
+#' @rdname manip_ties
 #' @importFrom tidygraph activate
 #' @export
 mutate_ties <- function(.data, ...){
@@ -80,7 +95,7 @@ mutate_ties <- function(.data, ...){
   out %>% tidygraph::activate(edges) %>% mutate(...) %>% activate(nodes)
 }
 
-#' @rdname add_ties
+#' @rdname manip_ties
 #' @importFrom dplyr rename
 #' @export
 rename_ties <- function(.data, ...){
@@ -89,7 +104,7 @@ rename_ties <- function(.data, ...){
   out %>% tidygraph::activate(edges) %>% dplyr::rename(...) %>% activate(nodes)
 }
 
-#' @rdname add_ties
+#' @rdname manip_ties
 #' @importFrom dplyr arrange
 #' @export
 arrange_ties <- function(.data, ...){
@@ -98,14 +113,16 @@ arrange_ties <- function(.data, ...){
   out %>% tidygraph::activate(edges) %>% dplyr::arrange(...) %>% activate(nodes)
 }
 
-#' @rdname add_ties
+#' @rdname manip_ties
 #' @importFrom tidygraph bind_edges
 #' @export
 bind_ties <- function(.data, ...){
-  tidygraph::bind_edges(.data, ...)
+  toAdd <- as_edgelist(...)
+  tidygraph::bind_edges(.data, toAdd) %>% 
+    arrange_ties(from, to)
 }
 
-#' @rdname add_ties 
+#' @rdname manip_ties 
 #' @importFrom igraph add_edges set_edge_attr E
 #' @importFrom dplyr mutate summarise across group_by everything ungroup %>%
 #' @export
@@ -144,7 +161,7 @@ join_ties <- function(.data, object2, attr_name) {
                        directed = is_directed(.data))
 }
 
-#' @rdname add_ties 
+#' @rdname manip_ties 
 #' @importFrom dplyr filter
 #' @export
 filter_ties <- function(.data, ...){
@@ -155,7 +172,7 @@ filter_ties <- function(.data, ...){
     tidygraph::activate(nodes)
 }
 
-#' @rdname add_ties
+#' @rdname manip_ties
 #' @importFrom dplyr select
 #' @export
 select_ties <- function(.data, ...){
@@ -164,7 +181,7 @@ select_ties <- function(.data, ...){
   out %>% tidygraph::activate(edges) %>% dplyr::select(...) %>% activate(nodes)
 }
 
-#' @rdname add_ties
+#' @rdname manip_ties
 #' @importFrom dplyr summarise
 #' @export
 summarise_ties <- function(.data, ...){
