@@ -84,9 +84,6 @@ test_that("node measure class works", {
   expect_s3_class(node_closeness(ison_adolescents), "node_measure")
   expect_s3_class(node_eigenvector(ison_adolescents), "node_measure")
   expect_s3_class(node_reach(ison_adolescents), "node_measure")
-  testplot <- plot(node_degree(ison_adolescents))
-  expect_equal(testplot$data$Score, unname(node_degree(ison_adolescents)))
-  # expect_equal(testplot$labels$y, "Frequency")
 })
 
 # ####### Centralization
